aboutsummaryrefslogtreecommitdiffstats
path: root/examples/charts/callout.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/charts/callout.py')
-rw-r--r--examples/charts/callout.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/charts/callout.py b/examples/charts/callout.py
index 54e8eaf24..666b2aae5 100644
--- a/examples/charts/callout.py
+++ b/examples/charts/callout.py
@@ -39,14 +39,14 @@
##
#############################################################################
"""PySide2 port of the Callout example from Qt v5.x"""
import sys
-from PySide2.QtWidgets import (QApplication, QGraphicsScene,
+from PySide6.QtWidgets import (QApplication, QGraphicsScene,
QGraphicsView, QGraphicsSimpleTextItem, QGraphicsItem)
-from PySide2.QtCore import Qt, QPointF, QRectF, QRect
-from PySide2.QtCharts import QtCharts
-from PySide2.QtGui import QPainter, QFont, QFontMetrics, QPainterPath, QColor
+from PySide6.QtCore import Qt, QPointF, QRectF, QRect
+from PySide6.QtCharts import QtCharts
+from PySide6.QtGui import QPainter, QFont, QFontMetrics, QPainterPath, QColor
class Callout(QGraphicsItem):
@@ -39,14 +39,14 @@
##
#############################################################################
-"""PySide2 port of the Callout example from Qt v5.x"""
+"""PySide6 port of the Callout example from Qt v5.x"""
import sys